@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+
 import sys
 import logging
 from collections import OrderedDict
@@ -8,6 +8,9 @@ import substance.command
 import substance.logs
 
 
+import warnings
+warnings.filterwarnings(action='ignore',module='.*paramiko.*')
+
 class SubstanceCLI(Program):
     """Substance CLI command"""
 
