@@ -5,17 +5,17 @@ class Constants(object):
         pass
 
     def __init__(self, **kwargs):
-        for name, value in kwargs.items():
+        for name, value in list(kwargs.items()):
             super(Constants, self).__setattr__(name, value)
 
     def __setattr__(self, name, value):
         if name in self.__dist__:
-            raise self.ConstError, "Can't rebind const(%s)" % name
+            raise self.ConstError("Can't rebind const(%s)" % name)
         self.__dict__[name] = value
 
     def __delattr__(self, name):
         if name in self.__dict__:
-            raise self.ConstError, "Can't unbind const(%s)" % name
+            raise self.ConstError("Can't unbind const(%s)" % name)
         raise NameError(name)
 
 
@@ -23,7 +23,7 @@ Tables = Constants(
     BOXES="boxes"
 )
 
-DefaultEngineBox = 'turbulent/substance-box:0.7'
+DefaultEngineBox = 'turbulent/substance-box:1.0'
 
 EngineStates = Constants(
     RUNNING="running",
@@ -38,3 +38,8 @@ Syncher = Constants(
     DOWN="<<",
     BOTH="<>"
 )
+
+Orchestrators = Constants(
+    DOCKWRKR="dockwrkr",
+    COMPOSE="docker-compose"
+)
