@@ -8,12 +8,13 @@ from substance.driver import Driver
 from substance.constants import (EngineStates)
 from substance.exceptions import (FileDoesNotExist)
 
-from vbox import (vboxManager)
-import network
-import machine
-from exceptions import *
+from .vbox import (vboxManager)
+from . import network
+from . import machine
+from .exceptions import *
 
 from netaddr import (IPAddress, IPNetwork)
+from functools import reduce
 
 logger = logging.getLogger(__name__)
 
@@ -43,7 +44,7 @@ class VirtualBoxDriver(Driver):
         self.logAdapter.info(
             "Generating default virtualbox config in %s" % self.config.getConfigFile())
         defaults = self.getDefaultConfig()
-        for kkk, vvv in defaults.iteritems():
+        for kkk, vvv in defaults.items():
             self.config.set(kkk, vvv)
         return self.config.saveConfig()
 
@@ -99,13 +100,27 @@ class VirtualBoxDriver(Driver):
 
         return OK(hoif)
 
+    def findInterface(self, netconfig, interfaces):
+        matches = list(filter(lambda x: x.v4ip == netconfig['gateway'], interfaces))
+        return OK(None) if len(matches) <= 0 else OK(matches[0])
+
     def provisionNetworking(self, netconfig):
         self.logAdapter.info(
             "Provisioning VirtualBox networking for substance")
-        ifm = network.addHostOnlyInterface()
-        if ifm.isFail():
-            return ifm
-        iface = ifm.getOK()
+
+        hoif = network.readHostOnlyInterfaces() \
+            .bind(defer(self.findInterface, netconfig))
+        if hoif.isFail():
+            return hoif
+        hoif = hoif.getOK()
+
+        if not hoif:
+            ifm = network.addHostOnlyInterface()
+            if ifm.isFail():
+                return ifm
+            iface = ifm.getOK()
+        else:
+            iface = hoif.name
 
         return network.configureHostOnlyInterface(iface, ip=netconfig['gateway'], netmask=netconfig['netmask']) \
             .then(defer(self.provisionDHCP, interface=iface, netconfig=netconfig)) \
@@ -116,7 +131,7 @@ class VirtualBoxDriver(Driver):
         self.logAdapter.info(
             "Provisioning DHCP service for host only interface")
         network.removeDHCP(interface).catch(lambda x: OK(interface)) \
-            .bind(defer(network.addDHCP, **netconfig))
+            .then(defer(network.addDHCP, interface, **netconfig))
 
     def saveInterface(self, iface):
         self.config.set('interface', iface)
@@ -201,7 +216,7 @@ class VirtualBoxDriver(Driver):
         basePort = 4500
         self.logAdapter.debug("Base port: %s" % basePort)
         self.logAdapter.debug("Desired port: %s" % desiredPort)
-        unavailable = map(lambda x: x.hostPort, usedPorts)
+        unavailable = [x.hostPort for x in usedPorts]
         port = desiredPort if desiredPort >= basePort else basePort
         while port in unavailable or port < basePort:
             self.logAdapter.debug("Port %s is in use." % port)
