@@ -11,6 +11,7 @@ from substance.exceptions import (
     FileSystemError, ShellCommandError, UserInterruptError)
 from substance.monads import *
 from threading import Thread
+from substance.platform import (isCygwin)
 
 # pylint: disable=W0232
 
@@ -19,10 +20,6 @@ logger = logging.getLogger(__name__)
 
 class Shell(object):
 
-    @staticmethod
-    def isCygwin():
-        return platform.system().startswith("CYGWIN")
-
     @staticmethod
     def printConfirm(msg, assumeYes=False):
         if assumeYes:
@@ -30,7 +27,7 @@ class Shell(object):
 
         logger.info(msg)
         try:
-            res = raw_input('Proceed? [N/y] ')
+            res = input('Proceed? [N/y] ')
             if res.lower().startswith('y'):
                 logger.info('... proceeding')
                 return OK(True)
@@ -43,7 +40,7 @@ class Shell(object):
         try:
             mustSleep = False
             if sudo and not shell:
-                if Shell.isCygwin():
+                if isCygwin():
                     mustSleep = True
                     cmd = ["cygstart", "--action=runas"] + cmd
                 else:
@@ -63,49 +60,54 @@ class Shell(object):
         logger.debug("COMMAND: %s", cmd)
         try:
             out = check_output(cmd, shell=True)
-            return OK(out.strip())
+            return OK(out.decode().strip())
         except CalledProcessError as err:
             return Fail(ShellCommandError(code=err.returncode, message=err.output, stdout=err.output))
 
     @staticmethod
     def procCommand(cmd, cwd=None):
         try:
-            logger.debug("COMMAND: %s", cmd)
+            logger.debug("PROC COMMAND: %s", cmd)
             proc = Popen(shlex.split(cmd), shell=False,
                          stdout=subprocess.PIPE, stderr=subprocess.PIPE, cwd=cwd)
             pout, perr = proc.communicate()
+            cmdOut = pout.decode()
+            cmdErr = perr.decode()
             if proc.returncode == 0:
-                return OK({"stdout": pout, "stderr": perr})
+                return OK({"stdout": cmdOut, "stderr": cmdErr})
             else:
-                return Fail(ShellCommandError(code=proc.returncode, message=pout, stdout=pout, stderr=perr))
+                return Fail(ShellCommandError(code=proc.returncode, message=cmdOut, stdout=cmdOut, stderr=cmdErr))
         except KeyboardInterrupt:
             logger.info("CTRL-C Received...Exiting.")
             return Fail(UserInterruptError())
 
+    @staticmethod
+    def readAppendFlush(stream, buffer=b'', amount=1):
+        the_bytes = stream.read(amount)
+        if the_bytes:
+            the_bytes += byte
+            sys.stdout.write(the_bytes.encode())
+            sys.stdout.flush()
+        return buffer
+
     @staticmethod
     def streamCommand(cmd, cwd=None, shell=False):
         try:
-            logger.debug("COMMAND: %s", cmd)
+            logger.debug("STREAM COMMAND: %s", cmd)
             proc = Popen(shlex.split(cmd), shell=shell,
                          stdout=subprocess.PIPE, stderr=subprocess.PIPE, cwd=cwd)
-            stdout = ''
-            stderr = ''
+            stdout = b''
+            stderr = b''
             while True:
-                d = proc.stdout.read(1)
-                if d != '':
-                    stdout += d
-                    sys.stdout.write(d)
-                    sys.stdout.flush()
+                stdout = readAppendFlush(sys.stdout, stdout, 1)
+                stderr = readAppendFlush(sys.stderr, stderr, 1)
 
-                de = proc.stderr.read(1)
-                if de != '':
-                    stderr += de
-                    sys.stderr.write(de)
-                    sys.stderr.flush()
-
-                if d == '' and de == '' and proc.poll() is not None:
+                if not d  and not de and proc.poll() is not None:
                     break
 
+            stdout = stdout.encode()
+            stderr = stderr.encode()
+
             if proc.returncode == 0:
                 return OK({"stdout": stdout, "stderr": stderr})
             else:
@@ -145,7 +147,7 @@ class Shell(object):
             return Fail(ShellCommandError(code=1, message="Failed to chmod %s: %s" % (path, err)))
 
     @staticmethod
-    def makeDirectory(path, mode=0750):
+    def makeDirectory(path, mode=0o750):
         if not os.path.exists(path):
             try:
                 os.makedirs(path, mode)
@@ -162,12 +164,6 @@ class Shell(object):
     def pathExists(path):
         return OK(path) if os.path.exists(path) else Fail(FileSystemError("Path %s does not exist." % path))
 
-    @staticmethod
-    def normalizePath(path):
-        if Shell.isCygwin():
-            path = check_output(["cygpath", "-w", path]).strip()
-        return path
-
     @staticmethod
     def rmFile(path):
         if os.path.isdir(path):
