@@ -2,7 +2,7 @@ import os
 import time
 import platform
 import logging
-import Queue
+import queue
 import fnmatch
 from collections import OrderedDict
 
@@ -10,7 +10,8 @@ from substance.monads import *
 from substance.logs import *
 from substance.shell import Shell
 from substance.exceptions import (SubstanceError)
-from substance.utils import pathComponents, getSupportFile
+from substance.utils import getSupportFile
+from substance.path import pathComponents
 from substance.constants import Syncher
 from substance.syncher import BaseSyncher
 
@@ -19,6 +20,7 @@ from subwatch.events import WatchEventHandler
 from subwatch.events import (WatchEvent, EVENT_TYPE_MODIFIED)
 
 from tornado import ioloop
+from functools import reduce
 
 logger = logging.getLogger(__name__)
 
@@ -106,7 +108,7 @@ class SubwatchSyncher(BaseSyncher):
 
     def expungeSynching(self, direction):
         dirs = self.synching[direction]
-        for dir in dirs.keys():
+        for dir in list(dirs.keys()):
             t = self.synching[direction][dir]
             if (time.time() - t) > 0:
                 logger.debug("Expiring ignore of (%s)%s" % (direction, dir))
@@ -256,7 +258,7 @@ class SubwatchSyncher(BaseSyncher):
                 if part == parts[-1]:
                     inc[p] = os.sep + "***"
 
-        for path, opt in inc.iteritems():
+        for path, opt in inc.items():
             path = ''.join(path.rsplit(os.sep, 1)
                            ) if path.endswith(os.sep) else path
             filters.append("+ " + path + opt)
@@ -324,11 +326,11 @@ class Rsync(object):
         return "\n".join(self.filters)
 
     def getCommandOpt(self):
-        return ''.join(self.opt.keys())
+        return ''.join(list(self.opt.keys()))
 
     def getCommandLongOpt(self):
         opts = ""
-        for k, v in self.longopt.iteritems():
+        for k, v in self.longopt.items():
             if v is True:
                 opts += " --%s" % k
             elif v:
@@ -371,6 +373,6 @@ class Rsync(object):
     def sync(self):
         op = Shell.call(self.getCommand())
         if op.isFail():
-            print("%s" % op)
+            print(("%s" % op))
             return op
         return OK(self)
