@@ -8,7 +8,7 @@ from substance.monads import *
 from substance import (Core, EngineProfile, Engine, Shell)
 from substance.utils import writeToFile, parseDotEnv, readDotEnv
 
-from substance.subenv import (SPECDIR, ENVFILE, CODELINK)
+from substance.subenv.constants import (SPECDIR, ENVFILE, CODELINK)
 from substance.subenv import SubenvAPI
 
 
@@ -65,8 +65,8 @@ class TestSubenv(tests.TestBase):
         filedata[os.path.join("conf", "tpl2.jinja")] = tpl2
 
         ops = []
-        for file, data in filedata.iteritems():
-            ops.append(Try.attempt(writeToFile, os.path.join(specpath, file), data))
+        for file, data in filedata.items():
+            ops.append(Try.attempt(writeToFile, os.path.join(specpath, file), data.encode()))
 
         self.assertIsInstance(Try.sequence(ops), OK)
 
@@ -84,7 +84,7 @@ class TestSubenv(tests.TestBase):
 
         self.assertTrue(os.path.isdir(envPath))
 
-        for f, fd in self.env['files'].iteritems():
+        for f, fd in self.env['files'].items():
             root, ext = os.path.splitext(f)
             if ext == '.jinja':
                 self.assertTrue(os.path.isfile(os.path.join(envPath, root)))
@@ -109,7 +109,7 @@ class TestSubenv(tests.TestBase):
         ls = self.api.ls()
         self.assertIsInstance(ls, OK)
         ls = ls.getOK()
-        names = map(lambda x: x.name, ls)
+        names = [x.name for x in ls]
         self.assertIn(self.env['name'], names)
 
         op = self.api.delete(self.env['name'])
@@ -118,7 +118,7 @@ class TestSubenv(tests.TestBase):
         ls = self.api.ls()
         self.assertIsInstance(ls, OK)
         ls = ls.getOK()
-        names = map(lambda x: x.name, ls)
+        names = [x.name for x in ls]
         self.assertNotIn(self.env['name'], names)
 
     def randString(self):
